@@ -1,13 +1,71 @@
-#######################################################################################################################
-#Exemplo
-#fator1<-c(rep(1,12),rep(2,12))
-#fator2<-c(rep(1,6),rep(2,6),rep(1,6),rep(2,6))
-#fator3<-c(rep(1,3),rep(2,3),rep(1,3),rep(2,3),rep(1,3),rep(2,3),rep(1,3),rep(2,3))
-#bloco<-rep(1:3,8)
-#resp<-c(10.0,10.8,9.8,10.3,11.3,10.3,9.7,10.1,10.2,9.4,11.6,9.1,9.2,8.6,10.1,9.3,10.3,9.1,11.5,9.5,10.8,10.7,10.4,9.6)
-#respAd<-c(10.6,11.3,9.6)
-#data.frame(fator1,fator2,fator3,repet,resp)
-#######################################################################################################################
+#' Fatorial triplo com um tratamento adicional em DBC
+#'
+#' \code{fat3.ad.dbc} Analisa experimentos em fatorial triplo
+#' com um tratamento adicional em Delineamento em Blocos
+#' Casualizados balanceado, considerando o modelo fixo.
+#' @param fator1 Vetor numerico ou complexo contendo os niveis
+#' do fator 1.
+#' @param fator2 Vetor numerico ou complexo contendo os niveis
+#' do fator 2.
+#' @param fator3 Vetor numerico ou complexo contendo os niveis
+#' do fator 3.
+#' @param bloco Vetor numerico ou complexo contendo os blocos.
+#' @param resp Vetor numerico ou complexo contendo a variavel
+#' resposta.
+#' @param respAd Vetor numerico ou complexo contendo a variavel
+#' resposta do tratamento adicional.
+#' @param quali Logico, se TRUE (default) na primeira posicao,
+#' os niveis do fator 1 sao entendidos como qualitativos, se
+#' FALSE, quantitativos; da mesma forma, a segunda posicao e
+#' referente aos niveis do fator 2 e a terceira aos niveis do
+#' fator 3.
+#' @param mcomp Permite escolher o teste de comparacao multipla;
+#' o \emph{default} e o teste de Tukey, contudo tem-se como
+#' outras opcoes: o teste LSD ('lsd'), o teste LSDB ('lsdb'),
+#' o teste de Duncan ('duncan'), o teste de SNK ('snk'), o
+#' teste de Scott-Knott ('sk'), o teste de comparacoes
+#' multiplas bootstrap ('ccboot') e o teste de Calinski e
+#' Corsten baseado na distribuicao F ('ccf').
+#' @param fac.names Permite nomear os fatores 1, 2 e 3.
+#' @param sigT Significancia a ser adotada pelo teste de
+#' comparacao multipla de medias; o default e 5\%.
+#' @param sigF Significancia a ser adotada pelo teste F da
+#' ANAVA; o default e 5\%.
+#' @details Os argumentos sigT e mcomp so serao utilizados
+#' quando os tratamentos forem qualitativos.
+#' @return Sao retornados os valores da analise de variancia
+#' do DBC em questao com um tratamento adicional,o teste de
+#' normalidade de Shapiro-Wilk para os residuos do modelo, o
+#' ajuste de modelos de regressao (caso de tratamentos
+#' quantitativos) ou os testes de comparacao de medias (caso de
+#' tratamentos qualitativos): teste de Tukey, teste de Duncan,
+#' teste t de Student (LSD), teste t de Bonferroni, teste de
+#' Student-Newman-Keuls (SNK), teste de Scott-Knott e teste de
+#' comparacoes multiplas bootstrap; com o desdobramento da
+#' interacao, caso esta seja significativa.
+#' @references HEALY, M. J. R. The analysis of a factorial
+#' experiment with additional treatments. Journal of
+#' Agricultural Science, Cambridge, v. 47, p. 205-206.
+#' 1956.
+#' @author Eric B Ferreira,
+#'  \email{eric.ferreira@@unifal-mg.edu.br}
+#' @author Denismar Alves Nogueira
+#' @author Portya Piscitelli Cavalcanti
+#' @note O \code{\link{graficos}} pode ser usado para
+#' construir os graficos da regressao e o
+#' \code{\link{plotres}} para analise do residuo da anava.
+#' @seealso \code{\link{fat2.dic}}, \code{\link{fat2.dbc}},
+#' \code{\link{fat3.dic}}, \code{\link{fat3.dbc}},
+#' \code{\link{fat2.ad.dic}}, \code{\link{fat2.ad.dbc}},
+#' \code{\link{fat3.ad.dic}} and \code{\link{fat3.ad.dbc}}.
+#' @examples
+#' data(ex6)
+#' attach(ex6)
+#' data(respAd)
+#' fat3.ad.dbc(fatorA, fatorB, fatorC, rep, resp, respAd,
+#' quali = c(TRUE, TRUE, TRUE), mcomp = "snk", fac.names =
+#' c("Fator A", "Fator B", "Fator C"), sigT=0.05, sigF = 0.05)
+#' @export
 
 fat3.ad.dbc<-function(fator1, fator2, fator3, bloco, resp, respAd, quali=c(TRUE,TRUE,TRUE), mcomp='tukey', fac.names=c('F1','F2','F3'), sigT=0.05, sigF=0.05) {
 
@@ -27,7 +85,6 @@ nv3<-length(summary(Fator3))   #Diz quantos niveis tem o fator 3.
 J<-(length(resp))/(nv1*nv2*nv3)
 n.trat2<-nv1*nv2
 n.trat3<-nv1*nv2*nv3
-
 lf1<-levels(Fator1)
 lf2<-levels(Fator2)
 lf3<-levels(Fator3)
@@ -41,7 +98,6 @@ SQab<-anavaF3[[1]][5,2]
 SQac<-anavaF3[[1]][6,2]
 SQbc<-anavaF3[[1]][7,2]
 SQabc<-anavaF3[[1]][8,2]
-
 glB=J-1
 gla=nv1-1
 glb=nv2-1
@@ -50,8 +106,6 @@ glab=(nv1-1)*(nv2-1)
 glac=(nv1-1)*(nv3-1)
 glbc=(nv2-1)*(nv3-1)
 glabc=(nv1-1)*(nv2-1)*(nv3-1)
-
-
 QMa=SQa/gla
 QMb=SQb/glb
 QMc=SQc/glc
@@ -73,21 +127,17 @@ TRAT<-factor(tabF3ad[,1])
 BLOCO<-factor(tabF3ad[,2])
 anava<-aov(tabF3ad[,3]~ BLOCO + TRAT)
 anavaTr<-summary(anava)
-
 SQB<-anavaTr[[1]][1,2]
 SQad<-anavaTr[[1]][2,2] - (SQa+SQb+SQc+SQab+SQac+SQbc+SQabc)
 SQE<-anavaTr[[1]][3,2]
 SQT<-anavaTr[[1]][1,2]+anavaTr[[1]][2,2]+anavaTr[[1]][3,2]
-
 glad=1
 glT=(nv1*nv2*nv3+1)*J-1
 glE=glT-(glB+gla+glb+glc+glab+glac+glbc+glabc+1)
-
 QMB=SQB/glB
 QMad=SQad/glad
 QME=SQE/glE
 QMT=SQT/glT
-
 FcB=QMB/QME
 Fca=QMa/QME
 Fcb=QMb/QME
@@ -97,7 +147,6 @@ Fcac=QMac/QME
 Fcbc=QMbc/QME
 Fcabc=QMabc/QME
 Fcad=QMad/QME
-
 pv.fs=c(1-pf(Fca,gla,glE), 1-pf(Fcb,glb,glE), 1-pf(Fcc,glc,glE))
 
 #Montando a tabela da ANAVA
@@ -115,7 +164,7 @@ print(an)
 cat('------------------------------------------------------------------------\n')
 pvalor<-c(1-pf(Fca,gla,glE), 1-pf(Fcb,glb,glE), 1-pf(Fcc,glc,glE), 1-pf(Fcab,glab,glE), 1-pf(Fcac,glac,glE), 1-pf(Fcbc,glbc,glE), 1-pf(Fcabc,glabc,glE))
 #CV
-cv<-round(sqrt(as.numeric(an[10,3]))/mean(col3)*100, 2)
+cv<-round(sqrt(QME)/mean(col3)*100, 2)
 cat('CV =',cv,'%\n')
 
 #Teste de normalidade
@@ -180,8 +229,8 @@ if(quali[i]==TRUE && pvalor[i]<=sigF) {
   if(mcomp=="ccboot"){
   ccboot(resp,fatores[,i],an[10,1],an[10,2],sigT)
                      }
-  if(mcomp=="ccf"){
-  ccf(resp,fatores[,i],an[10,1],an[10,2],sigT)
+  if(mcomp=="ccF"){
+  ccF(resp,fatores[,i],an[10,1],an[10,2],sigT)
                      }
                    }
 if(quali[i]==TRUE && pvalor[i]>sigF) {
@@ -215,7 +264,7 @@ cat('\n')
 
 }
 
-#Se a(s) interacao(es) dupla(s) for(em) significativa(s), desdobramento:
+#Se a(s) interacao(?es) dupla(s) for(em) significativa(s), desdobramento:
 
 #Interacao Fator1*Fator2
 if(1-pf(Fcabc,glabc,glE)>sigF && 1-pf(Fcab,glab,glE)<=sigF){
@@ -290,8 +339,8 @@ ii<-ii+1
                         if(mcomp=="ccboot"){
                         ccboot(resp[Fator2==lf2[i]],fatores[,1][Fator2==lf2[i]],an[10,1],an[10,2],sigT)
                                            }
-                        if(mcomp=="ccf"){
-                        ccf(resp[Fator2==lf2[i]],fatores[,1][Fator2==lf2[i]],an[10,1],an[10,2],sigT)
+                        if(mcomp=="ccF"){
+                        ccF(resp[Fator2==lf2[i]],fatores[,1][Fator2==lf2[i]],an[10,1],an[10,2],sigT)
                                            }
                       }
     else{  #regressao
@@ -379,8 +428,8 @@ ii<-ii+1
                         if(mcomp=="ccboot"){
                         ccboot(resp[Fator1==lf1[i]],fatores[,2][Fator1==lf1[i]],an[10,1],an[10,2],sigT)
                                            }
-                        if(mcomp=="ccf"){
-                        ccf(resp[Fator1==lf1[i]],fatores[,2][Fator1==lf1[i]],an[10,1],an[10,2],sigT)
+                        if(mcomp=="ccF"){
+                        ccF(resp[Fator1==lf1[i]],fatores[,2][Fator1==lf1[i]],an[10,1],an[10,2],sigT)
                                            }
                       }
     else{  #regressao
@@ -404,8 +453,8 @@ ii<-ii+1
 if(pvalor[5]>sigF && pvalor[6]>sigF) {
   cat('\nAnalisando os efeitos simples do fator ',fac.names[3],'
 ------------------------------------------------------------------------\n')
-  
-  i<-3 
+
+  i<-3
 {
   #Para os fatores QUALITATIVOS, teste de Tukey
   if(quali[i]==TRUE && pvalor[i]<=sigF) {
@@ -431,11 +480,11 @@ if(pvalor[5]>sigF && pvalor[6]>sigF) {
     if(mcomp=="ccboot"){
       ccboot(resp,fatores[,i],an[8,1],an[8,2],sigT)
     }
-    if(mcomp=="ccf"){
-      ccf(resp,fatores[,i],an[8,1],an[8,2],sigT)
+    if(mcomp=="ccF"){
+      ccF(resp,fatores[,i],an[8,1],an[8,2],sigT)
     }
   }
-  
+
   if(quali[i]==TRUE && pvalor[i]>sigF) {
     cat(fac.names[i])
     cat('\nDe acordo com o teste F, as medias desse fator sao estatisticamente iguais.\n')
@@ -445,13 +494,13 @@ if(pvalor[5]>sigF && pvalor[6]>sigF) {
     print(mean.table)
     cat('------------------------------------------------------------------------')
   }
-  
+
   #Para os fatores QUANTITATIVOS, regressao
   if(quali[i]==FALSE && pvalor[i]<=sigF){
     cat(fac.names[i])
     reg.poly(resp, fatores[,i], an[8,1],an[8,2], an[i,1], an[i,2])
   }
-  
+
   if(quali[i]==FALSE && pvalor[i]>sigF) {
     cat(fac.names[i])
     cat('\nDe acordo com o teste F, as medias desse fator sao estatisticamente iguais.\n')
@@ -461,10 +510,10 @@ if(pvalor[5]>sigF && pvalor[6]>sigF) {
     print(mean.table)
     cat('------------------------------------------------------------------------')
   }
-  
+
   cat('\n')
 }
-  
+
 }
 
 }
@@ -542,8 +591,8 @@ ii<-ii+1
                         if(mcomp=="ccboot"){
                         ccboot(resp[Fator3==lf3[i]],fatores[,1][Fator3==lf3[i]],an[10,1],an[10,2],sigT)
                                            }
-                        if(mcomp=="ccf"){
-                        ccf(resp[Fator3==lf3[i]],fatores[,1][Fator3==lf3[i]],an[10,1],an[10,2],sigT)
+                        if(mcomp=="ccF"){
+                        ccF(resp[Fator3==lf3[i]],fatores[,1][Fator3==lf3[i]],an[10,1],an[10,2],sigT)
                                            }
                       }
     else{  #regressao
@@ -631,8 +680,8 @@ ii<-ii+1
                         if(mcomp=="ccboot"){
                         ccboot(resp[Fator1==lf1[i]],fatores[,3][Fator1==lf1[i]],an[10,1],an[10,2],sigT)
                                            }
-                        if(mcomp=="ccf"){
-                        ccf(resp[Fator1==lf1[i]],fatores[,3][Fator1==lf1[i]],an[10,1],an[10,2],sigT)
+                        if(mcomp=="ccF"){
+                        ccF(resp[Fator1==lf1[i]],fatores[,3][Fator1==lf1[i]],an[10,1],an[10,2],sigT)
                                            }
                       }
     else{  #regressao
@@ -655,8 +704,8 @@ ii<-ii+1
 if(pvalor[4]>sigF && pvalor[6]>sigF) {
   cat('\nAnalisando os efeitos simples do fator ',fac.names[2],'
 ------------------------------------------------------------------------\n')
-  
-  i<-2 
+
+  i<-2
 {
   #Para os fatores QUALITATIVOS, teste de Tukey
   if(quali[i]==TRUE && pvalor[i]<=sigF) {
@@ -682,11 +731,11 @@ if(pvalor[4]>sigF && pvalor[6]>sigF) {
     if(mcomp=="ccboot"){
       ccboot(resp,fatores[,i],an[8,1],an[8,2],sigT)
     }
-    if(mcomp=="ccf"){
-      ccf(resp,fatores[,i],an[8,1],an[8,2],sigT)
+    if(mcomp=="ccF"){
+      ccF(resp,fatores[,i],an[8,1],an[8,2],sigT)
     }
   }
-  
+
   if(quali[i]==TRUE && pvalor[i]>sigF) {
     cat(fac.names[i])
     cat('\nDe acordo com o teste F, as medias desse fator sao estatisticamente iguais.\n')
@@ -696,13 +745,13 @@ if(pvalor[4]>sigF && pvalor[6]>sigF) {
     print(mean.table)
     cat('------------------------------------------------------------------------')
   }
-  
+
   #Para os fatores QUANTITATIVOS, regressao
   if(quali[i]==FALSE && pvalor[i]<=sigF){
     cat(fac.names[i])
     reg.poly(resp, fatores[,i], an[8,1],an[8,2], an[i,1], an[i,2])
   }
-  
+
   if(quali[i]==FALSE && pvalor[i]>sigF) {
     cat(fac.names[i])
     cat('\nDe acordo com o teste F, as medias desse fator sao estatisticamente iguais.\n')
@@ -712,10 +761,10 @@ if(pvalor[4]>sigF && pvalor[6]>sigF) {
     print(mean.table)
     cat('------------------------------------------------------------------------')
   }
-  
+
   cat('\n')
 }
-  
+
 }
 }
 
@@ -792,8 +841,8 @@ ii<-ii+1
                         if(mcomp=="ccboot"){
                         ccboot(resp[Fator3==lf3[i]],fatores[,2][Fator3==lf3[i]],an[10,1],an[10,2],sigT)
                                            }
-                        if(mcomp=="ccf"){
-                        ccf(resp[Fator3==lf3[i]],fatores[,2][Fator3==lf3[i]],an[10,1],an[10,2],sigT)
+                        if(mcomp=="ccF"){
+                        ccF(resp[Fator3==lf3[i]],fatores[,2][Fator3==lf3[i]],an[10,1],an[10,2],sigT)
                                            }
                       }
     else{  #regressao
@@ -881,8 +930,8 @@ ii<-ii+1
                         if(mcomp=="ccboot"){
                         ccboot(resp[Fator2==lf2[i]],fatores[,3][Fator2==lf2[i]],an[10,1],an[10,2],sigT)
                                            }
-                        if(mcomp=="ccf"){
-                        ccf(resp[Fator2==lf2[i]],fatores[,3][Fator2==lf2[i]],an[10,1],an[10,2],sigT)
+                        if(mcomp=="ccF"){
+                        ccF(resp[Fator2==lf2[i]],fatores[,3][Fator2==lf2[i]],an[10,1],an[10,2],sigT)
                                            }
                       }
     else{  #regressao
@@ -905,8 +954,8 @@ ii<-ii+1
 if(pvalor[4]>sigF && pvalor[5]>sigF) {
   cat('\nAnalisando os efeitos simples do fator ',fac.names[1],'
 ------------------------------------------------------------------------\n')
-  
-  i<-1 
+
+  i<-1
 {
   #Para os fatores QUALITATIVOS, teste de Tukey
   if(quali[i]==TRUE && pvalor[i]<=sigF) {
@@ -932,11 +981,11 @@ if(pvalor[4]>sigF && pvalor[5]>sigF) {
     if(mcomp=="ccboot"){
       ccboot(resp,fatores[,i],an[8,1],an[8,2],sigT)
     }
-    if(mcomp=="ccf"){
-      ccf(resp,fatores[,i],an[8,1],an[8,2],sigT)
+    if(mcomp=="ccF"){
+      ccF(resp,fatores[,i],an[8,1],an[8,2],sigT)
     }
   }
-  
+
   if(quali[i]==TRUE && pvalor[i]>sigF) {
     cat(fac.names[i])
     cat('\nDe acordo com o teste F, as medias desse fator sao estatisticamente iguais.\n')
@@ -946,13 +995,13 @@ if(pvalor[4]>sigF && pvalor[5]>sigF) {
     print(mean.table)
     cat('------------------------------------------------------------------------')
   }
-  
+
   #Para os fatores QUANTITATIVOS, regressao
   if(quali[i]==FALSE && pvalor[i]<=sigF){
     cat(fac.names[i])
     reg.poly(resp, fatores[,i], an[8,1],an[8,2], an[i,1], an[i,2])
   }
-  
+
   if(quali[i]==FALSE && pvalor[i]>sigF) {
     cat(fac.names[i])
     cat('\nDe acordo com o teste F, as medias desse fator sao estatisticamente iguais.\n')
@@ -962,10 +1011,10 @@ if(pvalor[4]>sigF && pvalor[5]>sigF) {
     print(mean.table)
     cat('------------------------------------------------------------------------')
   }
-  
+
   cat('\n')
 }
-  
+
 }
 }
 
@@ -1042,8 +1091,8 @@ ii<-0
                         if(mcomp=="ccboot"){
                         ccboot(resp[fatores[,2]==lf2[i] & fatores[,3]==lf3[j]],fatores[,1][Fator2==lf2[i] & Fator3==lf3[j]],an[10,1],an[10,2],sigT)
                                            }
-                        if(mcomp=="ccf"){
-                        ccf(resp[fatores[,2]==lf2[i] & fatores[,3]==lf3[j]],fatores[,1][Fator2==lf2[i] & Fator3==lf3[j]],an[10,1],an[10,2],sigT)
+                        if(mcomp=="ccF"){
+                        ccF(resp[fatores[,2]==lf2[i] & fatores[,3]==lf3[j]],fatores[,1][Fator2==lf2[i] & Fator3==lf3[j]],an[10,1],an[10,2],sigT)
                                            }
                       }
     else{  #regressao
@@ -1132,8 +1181,8 @@ for(k in 1:nv1) {
                         if(mcomp=="ccboot"){
                         ccboot(resp[fatores[,1]==lf1[k] & fatores[,3]==lf3[j]],fatores[,2][Fator1==lf1[k] & fatores[,3]==lf3[j]],an[10,1],an[10,2],sigT)
                                            }
-                        if(mcomp=="ccf"){
-                        ccf(resp[fatores[,1]==lf1[k] & fatores[,3]==lf3[j]],fatores[,2][Fator1==lf1[k] & fatores[,3]==lf3[j]],an[10,1],an[10,2],sigT)
+                        if(mcomp=="ccF"){
+                        ccF(resp[fatores[,1]==lf1[k] & fatores[,3]==lf3[j]],fatores[,2][Fator1==lf1[k] & fatores[,3]==lf3[j]],an[10,1],an[10,2],sigT)
                                            }
                       }
     else{  #regressao
@@ -1217,8 +1266,8 @@ for(k in 1:nv1) {
                         if(mcomp=="ccboot"){
                         ccboot(resp[fatores[,1]==lf1[k] & fatores[,2]==lf2[i]],fatores[,3][fatores[,1]==lf1[k] & fatores[,2]==lf2[i]],an[10,1],an[10,2],sigT)
                                            }
-                        if(mcomp=="ccf"){
-                        ccf(resp[fatores[,1]==lf1[k] & fatores[,2]==lf2[i]],fatores[,3][fatores[,1]==lf1[k] & fatores[,2]==lf2[i]],an[10,1],an[10,2],sigT)
+                        if(mcomp=="ccF"){
+                        ccF(resp[fatores[,1]==lf1[k] & fatores[,2]==lf2[i]],fatores[,3][fatores[,1]==lf1[k] & fatores[,2]==lf2[i]],an[10,1],an[10,2],sigT)
                                            }
                       }
     else{  #regressao
